@@ -2,7 +2,7 @@ from pydantic import BaseModel, validator
 from typing import Optional
 
 
-def normalize(val: str) -> str:
+def _normalize(val: str) -> str:
     if val is None:
         return None
     return val.lower()
@@ -12,10 +12,10 @@ class Location(BaseModel):
     name: str
     parent_name: Optional[str] = None
 
-    _name_val = validator('name', allow_reuse=True)(normalize)
+    _name_val = validator('name', allow_reuse=True)(_normalize)
     _parent_name_validator = validator(
         'parent_name', allow_reuse=True
-        )(normalize)
+        )(_normalize)
 
 
 class User(BaseModel):
@@ -29,5 +29,5 @@ class User(BaseModel):
     profile_pic_url: Optional[str] = None
     location: Location
 
-    _gender_val = validator('gender', allow_reuse=True)(normalize)
-    _role_val = validator('role', allow_reuse=True)(normalize)
+    _gender_val = validator('gender', allow_reuse=True)(_normalize)
+    _role_val = validator('role', allow_reuse=True)(_normalize)
